@@ -10,7 +10,7 @@ from typing import TYPE_CHECKING, Any, List, Optional
 import requests
 
 from .datatypes import Device, Tracker, TrackerConfig, TrackerData, TrackerStatus, User
-from .exceptions import HttpException
+from .exceptions import HttpException, UnknownAnswerScheme
 from .url_provider import UrlProvider
 
 if TYPE_CHECKING:
@@ -70,7 +70,10 @@ class Client:
         :raise requests.HTTPError: Unexpected HTTP error during API call
         """
         data = self._query(self._url_provider.user(user_id))
-        return User(**data)
+        try:
+            return User(**data)
+        except TypeError as err:
+            raise UnknownAnswerScheme(data, err.args[0]) from err
 
     def get_users(self) -> List[User]:
         """
@@ -87,7 +90,13 @@ class Client:
         :raise requests.HTTPError: Unexpected HTTP error during API call
         """
         data = self._query(self._url_provider.users())
-        return [User(**item) for item in data]
+        users: List[User] = []
+        for item in data:
+            try:
+                users.append(User(**item))
+            except TypeError as err:
+                raise UnknownAnswerScheme(item, err.args[0]) from err
+        return users
 
     def get_device(self, device_id: int) -> Device:
         """
@@ -203,7 +212,11 @@ class Client:
 
             # Pop returned results one by one and stop if max_count is reached.
             while len(data) > 0:
-                res.append(TrackerData(**data.pop(0)))
+                tracker_data = data.pop(0)
+                try:
+                    res.append(TrackerData(**tracker_data))
+                except TypeError as err:
+                    raise UnknownAnswerScheme(tracker_data, err.args[0]) from err
                 max_count -= 1
                 if max_count <= 0:
                     break
@@ -224,7 +237,10 @@ class Client:
         :rtype: TrackerStatus
         """
         data = self._query(self._url_provider.tracker_status(device_id=device.id))
-        return TrackerStatus(**data)
+        try:
+            return TrackerStatus(**data)
+        except TypeError as err:
+            raise UnknownAnswerScheme(data, err.args[0]) from err
 
     def get_tracker_config(self, device: Tracker) -> TrackerConfig:
         """
@@ -237,4 +253,7 @@ class Client:
         :rtype: TrackerConfig
         """
         data = self._query(self._url_provider.tracker_config(device_id=device.id))
-        return TrackerConfig(**data)
+        try:
+            return TrackerConfig(**data)
+        except TypeError as err:
+            raise UnknownAnswerScheme(data, err.args[0]) from err
